A ZST type that can be used to reference a bitmap object.
The module contains the RefBitmap type.
Structs
- OutOf
Bitmap Error - RefBitmap
- The ZST
RefBitmapreference withNbits.
A ZST type that can be used to reference a bitmap object.
The module contains the RefBitmap type.
RefBitmap reference with N bits.