Module string

Module string 

A UTF-8-encoded, growable but fixed-capacity string.

This module contains the StaticString type.

Structs

StaticString
The StaticString type is a fixed-capacity UTF-8 string object.
To estimate length N you need, consider the following UTF-8 facts:

Enums

InsertError

Functions

_static_fmt_str
This routine is the internal helper function for format_static macro. Do not use directly.